@@ -1,5 +1,8 @@
 package SVN::Web::action;
 
+use strict;
+use warnings;
+
 our $VERSION = 0.53;
 
 use POSIX qw();
@@ -93,10 +96,8 @@ L<OVERVIEW>, this would lead to:
 
 =item $self->{cgi}
 
-An instance of a CGI object corresponding to the current request.  This is
-normally an object from either the L<CGI> or L<CGI::Fast> modules, although
-it is possible to specify another class with the C<cgi_class> directive in
-F<config.yaml>.
+An instance of a CGI compatible object corresponding to the current request.  This is normally an object from either the L<CGI> or L<CGI::Fast> modules, although it is possible to specify another class with the C<cgi_class> directive in
+F<config.yaml>. Since we now use Plack, this is a L<Plack::Request> object.
 
 You can use this object to retrieve the values of any parameters passed to
 your action.
@@ -238,14 +239,19 @@ sub recent_interesting_rev {
     my $path = shift;
     my $rev  = shift;
 
-    my $ra  = $self->{repos}{ra};
+    my $ra = $self->{repos}{ra};
 
     my @log_result;
-    $ra->get_log([$path], $rev, 1, 1, 0, 1,
-                 sub { @log_result = @_; });
+
+    # warn "RPATH( $path )";
+    # warn "REV $rev";
+    # warn "BASE PATH IS " . $ra->get_repos_root;
+
+    $ra->get_log( [ $self->rpath($path) ],
+        $rev, 1, 1, 0, 1, sub { @log_result = @_; } );
 
     return @log_result if wantarray();
-    return $log_result[1];	# Revision number
+    return $log_result[1];    # Revision number
 }
 
 =head2 get_revs()
@@ -284,18 +290,21 @@ sub get_revs {
 
     my $exp_rev = $self->{cgi}->param('rev');
     my $yng_rev = $self->{repos}{ra}->get_latest_revnum();
-    my $act_rev = defined $exp_rev ? $self->recent_interesting_rev($path, $exp_rev) :
-                                     $self->recent_interesting_rev($path, $yng_rev);
+    my $act_rev =
+      defined $exp_rev
+      ? $self->recent_interesting_rev( $path, $exp_rev )
+      : $self->recent_interesting_rev( $path, $yng_rev );
 
     my $at_head = 0;
-    if(! defined $exp_rev) {
-	$at_head = 1;
-    } else {
-	if($exp_rev == $yng_rev) {
-	    $at_head = 1;
-	}
+    if ( !defined $exp_rev or $exp_rev eq '' ) {
+        $at_head = 1;
     }
-    return($exp_rev, $yng_rev, $act_rev, $at_head);
+    else {
+        if ( $exp_rev == $yng_rev ) {
+            $at_head = 1;
+        }
+    }
+    return ( $exp_rev, $yng_rev, $act_rev, $at_head );
 }
 
 =head2 format_svn_timestamp()
@@ -306,7 +315,7 @@ C<timezone> configuration directives.
 
 =cut
 
-my $tz_offset = undef;		# Cache the timezone offset
+my $tz_offset = undef;    # Cache the timezone offset
 
 sub format_svn_timestamp {
     my $self    = shift;
@@ -314,22 +323,24 @@ sub format_svn_timestamp {
 
     # Note: Buggy on Solaris
     # my $time = SVN::Core::time_from_cstring($cstring) / 1_000_000;
-    my(@time) = $cstring =~ /^(....)-(..)-(..)T(..):(..):(..)/;
+    my (@time) = $cstring =~ /^(....)-(..)-(..)T(..):(..):(..)/;
 
-    my $time = timegm_nocheck($time[5], $time[4],     $time[3],
-                              $time[2], $time[1] - 1, $time[0]);
+    my $time =
+      timegm_nocheck( $time[5], $time[4], $time[3], $time[2], $time[1] - 1,
+        $time[0] );
 
-    if($self->{config}->{timezone} eq 'local') {
-	return POSIX::strftime($self->{config}->{timedate_format},
-			       localtime($time));
+    if ( $self->{config}->{timezone} eq 'local' ) {
+        return POSIX::strftime( $self->{config}->{timedate_format},
+            localtime($time) );
     }
 
-    if((not defined $tz_offset) and ($self->{config}->{timezone} ne '')) {
-	$tz_offset = Time::Zone::tz_offset($self->{config}->{timezone});
-	$time += $tz_offset;
+    if ( ( not defined $tz_offset ) and ( $self->{config}->{timezone} ne '' ) )
+    {
+        $tz_offset = Time::Zone::tz_offset( $self->{config}->{timezone} );
+        $time += $tz_offset;
     }
 
-    return POSIX::strftime($self->{config}->{timedate_format}, gmtime($time));
+    return POSIX::strftime( $self->{config}->{timedate_format}, gmtime($time) );
 }
 
 =head1 CACHING
@@ -365,6 +376,8 @@ Exceptions, along with examples, are described in L<SVN::Web::X>.
 
 Copyright 2005-2007 by Nik Clayton C<< <nik@FreeBSD.org> >>.
 
+Copyright 2012 by Dean Hamstead C<< <dean@fragfest.com.au> >>.
+
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
@@ -372,4 +385,11 @@ See L<http://www.perl.com/perl/misc/Artistic.html>
 
 =cut
 
+sub rpath {
+    my ( $self, $p ) = @_;
+    my $path = $p || $self->{path};
+    $path =~ s{^/}{} if $path;
+    return $path
+}
+
 1;
